@@ -9,6 +9,7 @@ class WebsiteSubscription(WebsiteSubscription):
     def fill_values(self, values, is_company, logged, load_from_user=False):
         values = super(WebsiteSubscription, self).fill_values(values, is_company, logged, load_from_user=False)
         sub_req_obj = request.env['subscription.request']
-        fields_desc = sub_req_obj.sudo().fields_get(['join_commission'])
+        fields_desc = sub_req_obj.sudo().fields_get(['join_commission', 'discovery_channel'])
         values['commissions'] = fields_desc['join_commission']['selection']
+        values['channels'] = fields_desc['discovery_channel']['selection']
         return values
