@@ -30,3 +30,18 @@ class SubscriptionRequest(models.Model):
         help = 'Which commissions people would like to join.',
         string = 'Join commission'
     )
+    discovery_channel = fields.Selection(
+        selection = [
+            ('boca', _('Boca a boca')),
+            ('fulleto', _('Fulletó')),
+            ('radio', _('Ràdio')),
+            ('tv', _('TV')),
+            ('premsa', _('Premsa')),
+            ('xarxes', _('Xarxes socials')),
+            ('web', _('WEB')),
+            ('buscador', _('Buscador d’internet')),
+            ('altres', _('Altres'))
+        ],
+        help = 'How people find us.',
+        string = 'Discovery channel'
+    )
